package de.intevation.flys.exports;

import de.intevation.artifactdatabase.state.Attribute;
import de.intevation.artifactdatabase.state.DefaultSection;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ChartSection extends DefaultSection {

    public static final String TITLE_ATTR       = "title";
    public static final String SUBTITLE_ATTR    = "subtitle";
    public static final String DISPLAYGRID_ATTR = "display-grid";


    public ChartSection() {
        super("chart");
    }


    public void setTitle(String title) {
        if (title == null || title.length() == 0) {
            return;
        }

        Attribute attr = getAttribute(TITLE_ATTR);
        if (attr == null) {
            attr = new StringAttribute(TITLE_ATTR, title, true);
            addAttribute(TITLE_ATTR, attr);
        }
        else {
            attr.setValue(title);
        }
    }


    public String getTitle() {
        StringAttribute attr = (StringAttribute) getAttribute(TITLE_ATTR);
        return attr != null ? (String) attr.getValue() : null;
    }


    public void setSubtitle(String subtitle) {
        if (subtitle == null || subtitle.length() == 0) {
            return;
        }

        Attribute attr = getAttribute(SUBTITLE_ATTR);
        if (attr == null) {
            attr = new StringAttribute(SUBTITLE_ATTR, subtitle, true);
            addAttribute(SUBTITLE_ATTR, attr);
        }
        else {
            attr.setValue(subtitle);
        }
    }


    public String getSubtitle() {
        StringAttribute attr = (StringAttribute) getAttribute(SUBTITLE_ATTR);
        return attr != null ? (String) attr.getValue() : null;
    }


    public void setDisplayGird(boolean displayGrid) {
        Attribute attr = getAttribute(DISPLAYGRID_ATTR);
        if (attr == null) {
            attr = new BooleanAttribute(DISPLAYGRID_ATTR, displayGrid, true);
            addAttribute(DISPLAYGRID_ATTR, attr);
        }
        else {
            attr.setValue(displayGrid);
        }
    }


    public Boolean getDisplayGrid() {
        BooleanAttribute ba = (BooleanAttribute) getAttribute(DISPLAYGRID_ATTR);
        return ba != null ? (Boolean) ba.getValue() : null;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
